==> r-mail-1.0.0.zip: r-mail-1.0.0/index.php <==
<?

session_start ();

if (isset ($dec)) {
session_unregister (login);
session_unregister (password);
session_unregister (serveur_mail);
session_unregister (port_connexion);
session_unregister (domain);
session_unregister (temp_dir);
session_unregister (base_mysql);
session_unregister (user_mysql);
session_unregister (password_mysql);
session_unregister (nom_base_mysql);
session_unregister (annuaire_ldap);
session_unregister (port_ldap);
session_unregister (bind_dn);
session_unregister (carnet_adresse);
session_unregister (bind_adresses);

unset ($login);
unset ($password);
unset ($serveur_mail);
unset ($port_connexion);
unset ($domain);
unset ($temp_dir);
unset ($base_mysql);
unset ($user_mysql);
unset ($password_mysql);
unset ($nom_base_mysql);
unset ($annuaire_ldap);
unset ($port_ldap);
unset ($bind_dn);
unset ($carnet_adresse);
unset ($bind_adresses);

}

session_register (login);
session_register (password);

include 'conf.php';

if (isset ($evaluation)) {
include 'verification_parametres.php';
}

?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<title>R-MAIL V.1.0.0 - Authentification</title>
</head>
<body bgcolor="#ffffff" text="#000000" link="#000000" vlink="#000000" alink="#000000">

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
&#160;
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100%>
<tr><td align=middle valign=middle>
<!--<form action="verification_parametres.php" method="post">-->
<form action="index.php" method="post">

	<table border=0 width=50% bgcolor="#1FCBCB" cellpadding=5>
	<tr><td align=middle valign=middle>

		<table border=0 width=100% bgcolor="#9AC6CB" cellspacing=0>
		<tr><td colspan=2 align=middle>
		<font><b>Veuillez entrer votre nom d'utilisateur<br>et votre mot de passe<b></font>
		</td></tr>
		
		<tr><td align=middle>
		<br>
		<font size=3>Nom d'utilisateur</font>
		</td><td align=middle>
		<input type="text" name="login" size="20" maxlength="50">
		</td></tr>
		
		<tr><td align=middle>
		<font size=3>Mot de passe</font>
		</td><td align=middle>
		<input type="password" name="password" size="20" maxlength="50">
		</td></tr>
		
		<tr><td colspan=2 align=middle>
		<br>
		<input type="submit" name=evaluation value="envoi">
		</td></tr>
		</table>

	</td></tr>
	</table>

</form>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
&#160;
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>
</td></tr>
</table>

</body>
</html>

==> r-mail-1.0.2.zip: r-mail.1.0.2/index.php <==
<?

session_start ();

if (isset ($_GET ["dec"])) {

$_SESSION = array();
session_destroy();

}

if (!isset ($_POST ["login"]) && !isset ($_POST["password"])) {
	$_POST ["login"] = NULL;
	$_POST ["password"] = NULL;
}

$_SESSION ['login'] = $_POST ["login"];
$_SESSION ['password'] = $_POST ["password"];

include 'conf.php';
include 'langage.php';

if (isset ($_POST ["evaluation"])) {
include 'verification_parametres.php';
}

?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<title>R-MAIL - Authentification</title>
</head>
<body bgcolor="#ffffff" text="#000000" link="#000000" vlink="#000000" alink="#000000">

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL</u></b></font>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
&#160;
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100%>
<tr><td align=middle valign=middle>
<form action="index.php" method="post">

	<table border=0 width=50% bgcolor="#1FCBCB" cellpadding=5>
	<tr><td align=middle valign=middle>

		<table border=0 width=100% bgcolor="#9AC6CB" cellspacing=0>
		<tr><td colspan=2 align=middle>
		<font><b>
		<?
		echo $page_index[$lang][0];
		?>
		<b></font>
		</td></tr>
		
		<tr><td align=middle>
		<br>
		<font size=3>
		<?
		echo $page_index[$lang][1];
		?>
		</font>
		</td><td align=middle>
		<input type="text" name="login" size="20" maxlength="50">
		</td></tr>
		
		<tr><td align=middle>
		<font size=3>
		<?
		echo $page_index[$lang][2];
		?>
		</font>
		</td><td align=middle>
		<input type="password" name="password" size="20" maxlength="50">
		</td></tr>
		
		<tr><td colspan=2 align=middle>
		<br>
		<input type="submit" name=evaluation value=
		<?
		echo $page_index[$lang][3];
		?>
		>
		</td></tr>
		</table>

	</td></tr>
	</table>

</form>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
&#160;
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL</u></b></font>
</td></tr>
</table>

</body>
</html>
